/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2015 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.service;

import static org.fortiss.tooling.kernel.ToolingKernelActivator.getService;

import org.fortiss.tooling.kernel.extension.LogMessageHandler;
import org.fortiss.tooling.kernel.extension.data.ILogMessageContext;
import org.fortiss.tooling.kernel.extension.data.LogMessage;
import org.fortiss.tooling.kernel.internal.LoggingService;

/**
 * The logging service allows methods to emit {@link LogMessage}s that are processed by
 * {@link LogMessageHandler}s. The service is implemented in a broadcast manner such that each
 * handler is activated that accepts the emitted {@link LogMessage} with the given
 * {@link ILogMessageContext}.
 * 
 * One very useful use case is the possibility to emit messages from a non-UI plugin which are
 * displayed by handler registered in a UI plugin.
 * Another use case is the easy implementation of a logger that registers as a handler.
 * 
 * @author diewald
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating YELLOW Hash: CC2F51320ADEBD539F3522C30A12C974
 */
public interface ILoggingService {
	/**
	 * Returns the singleton instance of the service.
	 * 
	 * @deprecated
	 *             use {@link #getInstance()} instead
	 */
	@Deprecated
	public static final ILoggingService INSTANCE = new LoggingService();

	/** Returns the service instance. */
	public static ILoggingService getInstance() {
		return getService(ILoggingService.class);
	}

	/** Registers the logging message handler with the service. */
	// FIXME: why class here?
	void registerLogMessageHandler(LogMessageHandler handler, Class<?> modelElementClass);

	/**
	 * Triggers the processing method of the given {@link LogMessage} for all
	 * {@link LogMessageHandler}s that accept the {@link LogMessage} from the given
	 * {@link ILogMessageContext}.
	 */
	void processMessage(LogMessage message, ILogMessageContext context);
}
